Changelog
=========


0.1.7 (2023-08-17)
------------------

Fix
~~~
- Runtime dependencies. [Sebastian Krüger]

Changes
~~~~~~~
- Improve workflows. [Sebastian Krüger]
- Furo theme update. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]
- Gitignore cleanup. [Sebastian Krüger]


0.1.6 (2023-08-16)
------------------

Fix
~~~
- Some minor issues and more tests. [Sebastian Krüger]

Changes
~~~~~~~
- Coverage. [Sebastian Krüger]
- Pitch test. [Sebastian Krüger]
- Testing pitch and tempo again. [Sebastian Krüger]
- Testing loop with offset. [Sebastian Krüger]
- Fully test Amix.create. [Sebastian Krüger]
- Publish workflow. [Sebastian Krüger]
- Use mock. [Sebastian Krüger]
- Rename skeleton. [Sebastian Krüger]
- Add lint task. [Sebastian Krüger]

Other
~~~~~
- CHANGELOG. [Sebastian Krüger]
- README. [Sebastian Krüger]
- README. [Sebastian Krüger]
- README. [Sebastian Krüger]
- README. [Sebastian Krüger]
- README. [Sebastian Krüger]


0.1.5 (2023-08-14)
------------------

Feature
~~~~~~~
- Parts and segments filtering. [Sebastian Krüger]

Changes
~~~~~~~
- Readme and coverage report. [Sebastian Krüger]
- Pygments theme. [Sebastian Krüger]
- More tests. [Sebastian Krüger]
- Docs styling. [Sebastian Krüger]

Other
~~~~~
- CHANGELOG. [Sebastian Krüger]
- README. [Sebastian Krüger]


0.1.4 (2023-08-13)
------------------

Feature
~~~~~~~
- Deep merge parts. [Sebastian Krüger]
- Parts to clips. [Sebastian Krüger]
- Tempo filter. [Sebastian Krüger]

Changes
~~~~~~~
- Cleanup. [Sebastian Krüger]
- Fixture tests. [Sebastian Krüger]
- Github action. [Sebastian Krüger]
- Test action. [Sebastian Krüger]
- Snapshot testing. [Sebastian Krüger]
- Styling docs theme. [Sebastian Krüger]

Other
~~~~~
- CHANGELOG. [Sebastian Krüger]
- README. [Sebastian Krüger]


0.1.3 (2023-08-12)
------------------

Feature
~~~~~~~
- Selectrrronic. [Sebastian Krüger]

Fix
~~~
- Global bars optional. [Sebastian Krüger]

Changes
~~~~~~~
- Salmon primary color. [Sebastian Krüger]
- Theme colors. [Sebastian Krüger]
- Docs theme colors. [Sebastian Krüger]
- Change docs theme primary color. [Sebastian Krüger]
- Changelog. [Sebastian Krüger]

Other
~~~~~
- CHANGELOG. [Sebastian Krüger]
- README. [Sebastian Krüger]


0.1.2 (2023-08-12)
------------------

Feature
~~~~~~~
- Mailand. [Sebastian Krüger]
- Heidelberg --amend. [Sebastian Krüger]
- Heidelberg. [Sebastian Krüger]
- Templating. [Sebastian Krüger]
- Track. [Sebastian Krüger]
- Definition schema. [Sebastian Krüger]
- Multiple mixes. [Sebastian Krüger]
- Clip offset. [Sebastian Krüger]
- Loop field overloading. [Sebastian Krüger]
- Clip better overloading. [Sebastian Krüger]
- Mannheim. [Sebastian Krüger]
- Berlin. [Sebastian Krüger]
- Frankfurt. [Sebastian Krüger]
- Multi mix. [Sebastian Krüger]
- Set ffmpeg loglevel. [Sebastian Krüger]
- First Zurich example track draft. [Sebastian Krüger]
- Remove loops field to reduce complexity. [Sebastian Krüger]
- Filter references. [Sebastian Krüger]
- Timeline editing. [Sebastian Krüger]
- Ffmpeg. [Sebastian Krüger]

Fix
~~~
- Milano. [Sebastian Krüger]
- 1 bar rendering. [Sebastian Krüger]
- Afade filter usage. [Sebastian Krüger]
- Remove amix normalize. [Sebastian Krüger]
- Loop count. [Sebastian Krüger]

Changes
~~~~~~~
- Manifest. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]
- Docs. [Sebastian Krüger]
- Readme. [Sebastian Krüger]
- Readme. [Sebastian Krüger]
- Rename to amix. [Sebastian Krüger]
- Readme. [Sebastian Krüger]
- Docs. [Sebastian Krüger]
- Docs. [Sebastian Krüger]
- Workflow. [Sebastian Krüger]
- Docs. [Sebastian Krüger]
- Pre-commit. [Sebastian Krüger]
- Tweak mannheim. [Sebastian Krüger]
- Readme. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]
- Embed soundcloud. [Sebastian Krüger]

Other
~~~~~
- Fixed: clip overloading. [Sebastian Krüger]
- Initial commit. [Sebastian Krüger]
